% Initialization for the Zulu Non-Linear 6-dof Simulation
clear all
d2r=pi/180; r2d=180/pi;
h0=43031; x0=0; a0=4.73*d2r;                           % Init Altit h0=43031, Alpha=4.73*d2r;
decim=10;                                              % Plots Resolution
gm0=45.034*d2r; V0=436.7;                              % Init Gamma, speed: 45.034*d2r; V0=436.7;
Euler_0=[0, 49.766, 0]*d2r;                            % Init Attitude [0, 49.766, 0
pqr_0=[0, 0.0048,0];                                   % Init Rates [0, 0.0048,0] (rad/sec)
Uvw_0=[cos(a0),0,sin(a0)]*V0;                          % X,Y,Z Veloc Comp Body (ft/sec)
x_cg= -228.19; y_cg=0.0;  z_cg=0.005;                  % Init CG
cg=[x_cg, y_cg, z_cg];
x_ref=-228.19; y_ref=0; z_ref=0;                       % MRC
mrc=[x_ref, y_ref, z_ref];
accel=[-225, 0, 0];                                    % Accelerometer Location
Sref=47.308; ch=7.761; sp=7.761;
Nmch=16; Nalf=24; Nbet=3;
Tstg=91.2;                                             % First Stage Separation Time
Tst2=170.0;                                            % Second Stage Stage Separation Time

% Load the Commands from Trajectory
load Commands -ascii
timin= Commands(:,1);                                  % Time In
thecm= Commands(:,2);                                  % Theta Command (deg)
gamcm= Commands(:,3);                                  % Gamma Command (deg)
thrs1= Commands(:,4);                                  % Engine 1 Thrust (lb)
thrs2= Commands(:,5);                                  % Engine 2 Thrust (lb)
thrs3= Commands(:,6);                                  % Engine 3 Thrust (lb)
mssin= Commands(:,7);                                  % Vehicle Mass

ee=[0,0,0,0,0,0,0,0,0,1;
    0,0,0,0,0,0,0,0,1,0;
    0,0,0,0,0,0,0,1,0,0;
    0,0,0,0,0,0,1,0,0,0;
    0,0,0,0,0,1,0,0,0,0;
    0,0,0,0,1,0,0,0,0,0;
    0,0,0,1,0,0,0,0,0,0;
    0,0,1,0,0,0,0,0,0,0;
    0,1,0,0,0,0,0,0,0,0;
    1,0,0,0,0,0,0,0,0,0];
    
% Load the Mass Properties
load Zulu_Mass -ascii
msspr= ee*Zulu_Mass(:,1);                                % Vehi Mass from Mass Props
Ixxpr= ee*Zulu_Mass(:,2);                                % Ixx from Mass Props
Iyypr= ee*Zulu_Mass(:,3);                                % Iyy from Mass Props
Izzpr= ee*Zulu_Mass(:,4);                                % Izz from Mass Props
Ixypr= ee*Zulu_Mass(:,5);                                % Ixy from Mass Props
Ixzpr= ee*Zulu_Mass(:,6);                                % Ixz from Mass Props
Iyzpr= ee*Zulu_Mass(:,7);                                % Iyz from Mass Props
Xcgpr= ee*Zulu_Mass(:,8);                                % X_cg from Mass Props
Ycgpr= ee*Zulu_Mass(:,9);                                % Y_cg from Mass Props
Zcgpr= ee*Zulu_Mass(:,10);                               % Z_cg from Mass Props

% Engine Gimbals
tvc1=[-244.6, -8.7, 0.0];                                % Stage-1 TVC Locations
tvc2=[-244.6, +8.7, 0.0]; 
tvc3=[-244.6,  0.0, 0.0];                                % Stage-2 TVC Locations
tvc4=[-200.0, 0.0, 0.06];                                % Stage-3 TVC Locations
rcs1=[-120.0, -4.0, -0.0];                               % Left  RCS Location
rcs2=[-120.0, +4.0, -0.0];                               % Right RCS Location

% Load Aero Data for the Base Vehicle
[CX, CY, CZ, Cl, Cm, Cn] = Stage1_Aero_Coeff;                                
[CX2,CY2,CZ2,Cl2,Cm2,Cn2]= Stage2_Aero_Coeff;                                
Machs=[0.35, 0.6, 0.8, 0.85, 0.9, 0.95, 1.1,1.3,1.4,1.46,1.57,1.82,2.7,3.44,5,10];
Betas=[-5, 0, 5];
Alfas=[-20,-4,-2,0,2,4,6,8,10,15,20,25,30,35,40,50,60,70,80,90,100,120,140,160];
Alfa2=[-4, -3, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10];

% Load FCS Gains
load FCS_Gains -ascii
timgn  = FCS_Gains(:,1);                                  % Gains Time In
Kml1   = FCS_Gains(:,2);                                  % Roll Mixing Logic Gain
Kml2   = FCS_Gains(:,3);                                  % Ptch Mixing Logic Gain
Kml3   = FCS_Gains(:,4);                                  % Yaw  Mixing Logic Gain

Kq_the = FCS_Gains(:,5);                                  % Pitch Kq_theta
Kq_q   = FCS_Gains(:,6);                                  % Pitch Kq_q (pitch rate)
Kq_alf = FCS_Gains(:,7);                                  % Pitch Kq_alpha
Kq_gmi = FCS_Gains(:,8);                                  % Pitch Kq_gamma_integral

Kp_phi = FCS_Gains(:,9);                                  % Roll Kp_phi (roll attitude)
Kp_p   = FCS_Gains(:,10);                                 % Roll Kp_p (roll rate)
Kp_psi = FCS_Gains(:,11);                                 % Roll Kp_psi (yaw attitude)
Kp_r   = FCS_Gains(:,12);                                 % Roll Kp_r (yaw rate)
Kp_bet = FCS_Gains(:,13);                                 % Roll Kp_beta

Kr_phi = FCS_Gains(:,14);                                 % Yaw Kr_phi (roll attitude)
Kr_p   = FCS_Gains(:,15);                                 % Yaw Kr_p (roll rate)
Kr_psi = FCS_Gains(:,16);                                 % Yaw Kr_psi (yaw attitude)
Kr_r   = FCS_Gains(:,17);                                 % Yaw Kr_r (yaw rate)
Kr_bet = FCS_Gains(:,18);                                 % Yaw Kr_beta

% Load Estimator Gains
load Estim_Gains -ascii
timest = Estim_Gains(:,1);                                % Gains Time
Cz_alf = Estim_Gains(:,2);                                % Cz_alpha
Cz0    = Estim_Gains(:,3);                                % 
Cy_bet = Estim_Gains(:,4);                                % Cy_beta



